==> plugin.video.watchparsilandtv-1.0.0.zip: plugin.video.watchparsilandtv/default.py <==
# -*- coding: utf-8 -*-
import urllib
import urllib2
import re
import os
import xbmcplugin
import xbmcgui
import xbmcaddon
import xbmcvfs
import traceback
import requests
from socket import error as socket_error
import socket
OO0o = 500
try :
 from xml . sax . saxutils import escape
except : traceback . print_exc ( )
try :
 import json
except :
 import simplejson as json
 if 81 - 81: Iii1I1 + OO0O0O % iiiii % ii1I - ooO0OO000o
ii11i = False ;
if ii11i :
 if 66 - 66: iIiI * iIiiiI1IiI1I1 * o0OoOoOO00
 if 27 - 27: OOOo0 / Oo - Ooo00oOo00o . I1IiI
 try :
  import pysrc . pydevd as pydevd
  if 73 - 73: OOooOOo / ii11ii1ii
  pydevd . settrace ( 'localhost' , stdoutToServer = True , stderrToServer = True )
 except ImportError :
  sys . stderr . write ( "Error: " +
 "You must add org.python.pydev.debug.pysrc to your PYTHONPATH." )
  sys . exit ( 1 )
  if 94 - 94: OoOO + OoOO0ooOOoo0O + o0000oOoOoO0o * o00O0oo
  if 97 - 97: oO0o0ooO0 - OO0O0O / ii1I * Ooo00oOo00o
oO0o0oO0o = xbmcaddon . Addon ( 'plugin.video.watchparsilandtv' )
II = oO0o0oO0o . getAddonInfo ( 'version' )
OoI1Ii11I1Ii1i = xbmc . translatePath ( oO0o0oO0o . getAddonInfo ( 'path' ) . decode ( 'utf-8' ) )
Ooo = xbmc . translatePath ( os . path . join ( 'special://home/addons/plugin.video.watchparsilandtv/' ) )
o0oOoO00o = os . path . join ( OoI1Ii11I1Ii1i , 'icon.png' )
i1 = oO0o0oO0o . getSetting ( 'debug' )
if 64 - 64: Ooo00oOo00o % o0OoOoOO00
def i1I1Iiii1111 ( string ) :
 if i1 == 'true' :
  xbmc . log ( "[addon.WatchParsiLandTV-%s]: %s" % ( II , string ) )
  if 22 - 22: OoOO . o0000oOoOoO0o
def I11 ( url , headers = None ) :
 try :
  if headers is None :
   headers = { 'User-agent' : 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:19.0) Gecko/20100101 Firefox/19.0' }
   if 98 - 98: i11iIiiIii * iIiI % OoOO0ooOOoo0O * OoOO0ooOOoo0O * ooO0OO000o
  o0o0Oo0oooo0 = urllib2 . Request ( url , None , headers )
  oO0O0o0o0 = urllib2 . urlopen ( o0o0Oo0oooo0 )
  i1iIIII = oO0O0o0o0 . read ( )
  oO0O0o0o0 . close ( )
  return i1iIIII
 except urllib2 . URLError , I1 :
  print 'URL Error : ' + url
  if hasattr ( I1 , 'code' ) :
   print 'A request failed with error code - %s.' % I1 . code
  elif hasattr ( I1 , 'reason' ) :
   print 'Failed to reach a server.'
   print 'Reason: ' % I1 . reason
 except Exception , O0OoOoo00o :
  print type ( O0OoOoo00o )
  if 31 - 31: ooO0OO000o + o0OoOoOO00 . o00O0oo
def OoOooOOOO ( url ) :
 try :
  i1I1Iiii1111 ( 'checkUrl Result : %s ' % url )
  i11iiII = requests . head ( url , timeout = 15 )
  i1I1Iiii1111 ( 'checkUrl Result : %s ' % i11iiII . status_code )
  if i11iiII . status_code < 400 :
   return True
  else :
   return False
 except :
  i1I1Iiii1111 ( 'checkUrl Result ERROR , Maybe timeout!' )
  return False
  if 34 - 34: OOooOOo % iiiii / ii1I . OoOO0ooOOoo0O + Iii1I1
def I1Ii ( title , thumbnail , link , mediaType = 'Video' ) :
 o0oOo0Ooo0O = xbmcgui . ListItem ( label = title , iconImage = thumbnail , thumbnailImage = thumbnail , path = link )
 if 81 - 81: Ooo00oOo00o * o0000oOoOoO0o * ii11ii1ii - OoOO0ooOOoo0O - Oo
 if 90 - 90: ooO0OO000o + I1IiI / Oo % ooO0OO000o - Iii1I1
 if 29 - 29: Oo / OO0O0O
 if 24 - 24: Iii1I1 % Oo + ii1I + o00O0oo + Ooo00oOo00o
 if 70 - 70: iIiiiI1IiI1I1 % iIiiiI1IiI1I1 . o0000oOoOoO0o % o0OoOoOO00 * Oo % I1IiI
 if 23 - 23: i11iIiiIii + iIiI
 if 68 - 68: OOOo0 . I1IiI . i11iIiiIii
 if 40 - 40: I1IiI . OOOo0 . iIiiiI1IiI1I1 . ii1I
 o0oOo0Ooo0O . setInfo ( type = mediaType , infoLabels = { "Title" : title } )
 xbmc . Player ( ) . play ( item = link , listitem = o0oOo0Ooo0O )
 if 33 - 33: OoOO + ooO0OO000o % i11iIiiIii . oO0o0ooO0 - iIiI
def O00oooo0O ( media_url , icon = "DefaultVideo.png" ) :
 try :
  import CustomPlayer
  IiI1i11iii1 = CustomPlayer . MyXBMCPlayer ( )
  oo0Oo00Oo0 = xbmcgui . ListItem ( label = str ( name ) , iconImage = icon , thumbnailImage = xbmc . getInfoImage ( "ListItem.Thumb" ) , path = media_url )
  IiI1i11iii1 . play ( media_url , oo0Oo00Oo0 )
  xbmc . sleep ( 1000 )
  while IiI1i11iii1 . is_active :
   xbmc . sleep ( 200 )
 except :
  traceback . print_exc ( )
 return ''
 if 79 - 79: iIiiiI1IiI1I1 + iIiI - OoOO0ooOOoo0O
def oO00O00o0OOO0 ( media_url , name , iconImage , proxyip , port , proxyuser = None , proxypass = None ) :
 if 27 - 27: Iii1I1 % ii1I * I1IiI + i11iIiiIii + iiiii * ii1I
 o0oo0o0O00OO = xbmcgui . DialogProgress ( )
 o0oo0o0O00OO . create ( 'Progress' , 'Playing with custom proxy' )
 o0oo0o0O00OO . update ( 10 , "" , "setting proxy.." , "" )
 o0oO = False
 I1i1iii = ''
 if 20 - 20: Oo
 try :
  if 77 - 77: OOOo0 / ii11ii1ii
  I1i1iii = getConfiguredProxy ( )
  print 'existing_proxy' , I1i1iii
  if 98 - 98: OO0O0O / ii1I / i11iIiiIii / Oo
  if 28 - 28: OOooOOo - o0000oOoOoO0o . o0000oOoOoO0o + OOOo0 - iiiii + Iii1I1
  if not proxyuser == None :
   setKodiProxy ( proxyip + ':' + port + ':0:' + proxyuser + '@' + proxypass )
  else :
   setKodiProxy ( proxyip + ':' + port + ':0' )
   if 95 - 95: o0OoOoOO00 % I1IiI . Iii1I1
   if 15 - 15: oO0o0ooO0 / OoOO . OoOO - ii1I
  o0oO = True
  o0oo0o0O00OO . update ( 80 , "" , "setting proxy complete, now playing" , "" )
  if 53 - 53: o0000oOoOoO0o + iIiI * I1IiI
  o0oo0o0O00OO . close ( )
  o0oo0o0O00OO = None
  import CustomPlayer
  IiI1i11iii1 = CustomPlayer . MyXBMCPlayer ( )
  oo0Oo00Oo0 = xbmcgui . ListItem ( label = str ( name ) , iconImage = iconImage , thumbnailImage = xbmc . getInfoImage ( "ListItem.Thumb" ) , path = media_url )
  IiI1i11iii1 . play ( media_url , oo0Oo00Oo0 )
  xbmc . sleep ( 1000 )
  while IiI1i11iii1 . is_active :
   xbmc . sleep ( 200 )
 except :
  traceback . print_exc ( )
 if o0oo0o0O00OO :
  o0oo0o0O00OO . close ( )
 if o0oO :
  if 61 - 61: ii1I * OOooOOo / iiiii . i11iIiiIii . OOOo0
  setKodiProxy ( I1i1iii )
  if 60 - 60: ii11ii1ii / ii11ii1ii
 return ''
 if 46 - 46: OoOO * OOooOOo - o0OoOoOO00 * I1IiI - o00O0oo
def oo0 ( ) :
 import zipfile , StringIO
 i1I1Iiii1111 ( "Checking for new version..." )
 for o00 in os . listdir ( Ooo ) :
  if re . search ( 'changelog-.*.txt' , o00 ) :
   OooOooo = re . search ( 'changelog-(.+?).txt' , o00 )
   OooOooo = OooOooo . group ( 1 )
 try :
  O000oo0O = urllib2 . Request ( "http://parsiland.net/repo/plugin.video.watchparsilandtv/" )
  OOOO = urllib2 . urlopen ( O000oo0O ) . read ( )
 except :
  i1I1Iiii1111 ( "An error happened checking for update" )
  return
 i11i1 = re . search ( r'changelog-(.+?)[.]txt' , OOOO )
 i11i1 = i11i1 . group ( 1 )
 dir = xbmc . translatePath ( os . path . join ( 'special://home/addons/' ) )
 if float ( i11i1 [ 2 : ] ) > float ( OooOooo [ 2 : ] ) :
  i1I1Iiii1111 ( "New version is available. " + i11i1 )
  IIIii1II1II = 'http://parsiland.net/repo/plugin.video.watchparsilandtv/plugin.video.watchparsilandtv-' + i11i1 + ".zip"
  try :
   i11iiII = requests . get ( IIIii1II1II , stream = True )
   if i11iiII . status_code == 200 :
    i1I1iI = zipfile . ZipFile ( StringIO . StringIO ( i11iiII . content ) )
    i1I1iI . extractall ( dir )
    xbmc . executebuiltin ( 'UpdateLocalAddons()' )
    xbmc . executebuiltin ( 'ReloadSkin()' )
    xbmcgui . Dialog ( ) . notification ( "[COLOR red]P[/COLOR][COLOR white]arsiLandTV[/COLOR]" , "Add-on updated" , Ooo + "icon.png" , 3000 , False )
    i1I1Iiii1111 ( "Updated successfully" )
   else : i1I1Iiii1111 ( "Updating wasn't successfull, status_code not OK , " + str ( i11iiII . status_code ) )
  except :
   i1I1Iiii1111 ( "Exception happened! :(" )
   return
 else :
  i1I1Iiii1111 ( "Awesome , You are using latest version." )
  if 93 - 93: OO0O0O % I1IiI * ii1I
  if 16 - 16: Iii1I1 - o00O0oo * OO0O0O + OoOO0ooOOoo0O
oo0 ( )
o0oOo0Ooo0O = xbmcgui . ListItem ( 'manoto' )
o0oOo0Ooo0O . setArt ( { 'thumb' : Ooo + "icon.png" } )
o0oOo0Ooo0O . setInfo ( 'video' , { 'plot' : 'Live Stream' } )
xbmc . Player ( ) . play ( "rtmp://vps.parsiland.net:1935/live/ParsiLand" , o0oOo0Ooo0O , False )
if 50 - 50: ooO0OO000o - oO0o0ooO0 * Ooo00oOo00o / o00O0oo + Oo

==> plugin.video.watchparsilandtv-1.0.1.zip: plugin.video.watchparsilandtv/default.py <==
# -*- coding: utf-8 -*-
import urllib
import urllib2
import re
import os
import xbmcplugin
import xbmcgui
import xbmcaddon
import xbmcvfs
import traceback
import requests
from socket import error as socket_error
import socket
OO0o = 500
try :
 from xml . sax . saxutils import escape
except : traceback . print_exc ( )
try :
 import json
except :
 import simplejson as json
 if 81 - 81: Iii1I1 + OO0O0O % iiiii % ii1I - ooO0OO000o
ii11i = False ;
if ii11i :
 if 66 - 66: iIiI * iIiiiI1IiI1I1 * o0OoOoOO00
 if 27 - 27: OOOo0 / Oo - Ooo00oOo00o . I1IiI
 try :
  import pysrc . pydevd as pydevd
  if 73 - 73: OOooOOo / ii11ii1ii
  pydevd . settrace ( 'localhost' , stdoutToServer = True , stderrToServer = True )
 except ImportError :
  sys . stderr . write ( "Error: " +
 "You must add org.python.pydev.debug.pysrc to your PYTHONPATH." )
  sys . exit ( 1 )
  if 94 - 94: OoOO + OoOO0ooOOoo0O + o0000oOoOoO0o * o00O0oo
  if 97 - 97: oO0o0ooO0 - OO0O0O / ii1I * Ooo00oOo00o
oO0o0oO0o = xbmcaddon . Addon ( 'plugin.video.watchparsilandtv' )
II = oO0o0oO0o . getAddonInfo ( 'version' )
OoI1Ii11I1Ii1i = xbmc . translatePath ( oO0o0oO0o . getAddonInfo ( 'path' ) . decode ( 'utf-8' ) )
Ooo = xbmc . translatePath ( os . path . join ( 'special://home/addons/plugin.video.watchparsilandtv/' ) )
o0oOoO00o = os . path . join ( OoI1Ii11I1Ii1i , 'icon.png' )
i1 = oO0o0oO0o . getSetting ( 'debug' )
if 64 - 64: Ooo00oOo00o % o0OoOoOO00
def i1I1Iiii1111 ( string ) :
 if i1 == 'true' :
  xbmc . log ( "[addon.WatchParsiLandTV-%s]: %s" % ( II , string ) )
  if 22 - 22: OoOO . o0000oOoOoO0o
def I11 ( url , headers = None ) :
 try :
  if headers is None :
   headers = { 'User-agent' : 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:19.0) Gecko/20100101 Firefox/19.0' }
   if 98 - 98: i11iIiiIii * iIiI % OoOO0ooOOoo0O * OoOO0ooOOoo0O * ooO0OO000o
  o0o0Oo0oooo0 = urllib2 . Request ( url , None , headers )
  oO0O0o0o0 = urllib2 . urlopen ( o0o0Oo0oooo0 )
  i1iIIII = oO0O0o0o0 . read ( )
  oO0O0o0o0 . close ( )
  return i1iIIII
 except urllib2 . URLError , I1 :
  print 'URL Error : ' + url
  if hasattr ( I1 , 'code' ) :
   print 'A request failed with error code - %s.' % I1 . code
  elif hasattr ( I1 , 'reason' ) :
   print 'Failed to reach a server.'
   print 'Reason: ' % I1 . reason
 except Exception , O0OoOoo00o :
  print type ( O0OoOoo00o )
  if 31 - 31: ooO0OO000o + o0OoOoOO00 . o00O0oo
def OoOooOOOO ( url ) :
 try :
  i1I1Iiii1111 ( 'checkUrl Result : %s ' % url )
  i11iiII = requests . head ( url , timeout = 15 )
  i1I1Iiii1111 ( 'checkUrl Result : %s ' % i11iiII . status_code )
  if i11iiII . status_code < 400 :
   return True
  else :
   return False
 except :
  i1I1Iiii1111 ( 'checkUrl Result ERROR , Maybe timeout!' )
  return False
  if 34 - 34: OOooOOo % iiiii / ii1I . OoOO0ooOOoo0O + Iii1I1
def I1Ii ( title , thumbnail , link , mediaType = 'Video' ) :
 o0oOo0Ooo0O = xbmcgui . ListItem ( label = title , iconImage = thumbnail , thumbnailImage = thumbnail , path = link )
 if 81 - 81: Ooo00oOo00o * o0000oOoOoO0o * ii11ii1ii - OoOO0ooOOoo0O - Oo
 if 90 - 90: ooO0OO000o + I1IiI / Oo % ooO0OO000o - Iii1I1
 if 29 - 29: Oo / OO0O0O
 if 24 - 24: Iii1I1 % Oo + ii1I + o00O0oo + Ooo00oOo00o
 if 70 - 70: iIiiiI1IiI1I1 % iIiiiI1IiI1I1 . o0000oOoOoO0o % o0OoOoOO00 * Oo % I1IiI
 if 23 - 23: i11iIiiIii + iIiI
 if 68 - 68: OOOo0 . I1IiI . i11iIiiIii
 if 40 - 40: I1IiI . OOOo0 . iIiiiI1IiI1I1 . ii1I
 o0oOo0Ooo0O . setInfo ( type = mediaType , infoLabels = { "Title" : title } )
 xbmc . Player ( ) . play ( item = link , listitem = o0oOo0Ooo0O )
 if 33 - 33: OoOO + ooO0OO000o % i11iIiiIii . oO0o0ooO0 - iIiI
def O00oooo0O ( media_url , icon = "DefaultVideo.png" ) :
 try :
  import CustomPlayer
  IiI1i11iii1 = CustomPlayer . MyXBMCPlayer ( )
  oo0Oo00Oo0 = xbmcgui . ListItem ( label = str ( name ) , iconImage = icon , thumbnailImage = xbmc . getInfoImage ( "ListItem.Thumb" ) , path = media_url )
  IiI1i11iii1 . play ( media_url , oo0Oo00Oo0 )
  xbmc . sleep ( 1000 )
  while IiI1i11iii1 . is_active :
   xbmc . sleep ( 200 )
 except :
  traceback . print_exc ( )
 return ''
 if 79 - 79: iIiiiI1IiI1I1 + iIiI - OoOO0ooOOoo0O
def oO00O00o0OOO0 ( media_url , name , iconImage , proxyip , port , proxyuser = None , proxypass = None ) :
 if 27 - 27: Iii1I1 % ii1I * I1IiI + i11iIiiIii + iiiii * ii1I
 o0oo0o0O00OO = xbmcgui . DialogProgress ( )
 o0oo0o0O00OO . create ( 'Progress' , 'Playing with custom proxy' )
 o0oo0o0O00OO . update ( 10 , "" , "setting proxy.." , "" )
 o0oO = False
 I1i1iii = ''
 if 20 - 20: Oo
 try :
  if 77 - 77: OOOo0 / ii11ii1ii
  I1i1iii = getConfiguredProxy ( )
  print 'existing_proxy' , I1i1iii
  if 98 - 98: OO0O0O / ii1I / i11iIiiIii / Oo
  if 28 - 28: OOooOOo - o0000oOoOoO0o . o0000oOoOoO0o + OOOo0 - iiiii + Iii1I1
  if not proxyuser == None :
   setKodiProxy ( proxyip + ':' + port + ':0:' + proxyuser + '@' + proxypass )
  else :
   setKodiProxy ( proxyip + ':' + port + ':0' )
   if 95 - 95: o0OoOoOO00 % I1IiI . Iii1I1
   if 15 - 15: oO0o0ooO0 / OoOO . OoOO - ii1I
  o0oO = True
  o0oo0o0O00OO . update ( 80 , "" , "setting proxy complete, now playing" , "" )
  if 53 - 53: o0000oOoOoO0o + iIiI * I1IiI
  o0oo0o0O00OO . close ( )
  o0oo0o0O00OO = None
  import CustomPlayer
  IiI1i11iii1 = CustomPlayer . MyXBMCPlayer ( )
  oo0Oo00Oo0 = xbmcgui . ListItem ( label = str ( name ) , iconImage = iconImage , thumbnailImage = xbmc . getInfoImage ( "ListItem.Thumb" ) , path = media_url )
  IiI1i11iii1 . play ( media_url , oo0Oo00Oo0 )
  xbmc . sleep ( 1000 )
  while IiI1i11iii1 . is_active :
   xbmc . sleep ( 200 )
 except :
  traceback . print_exc ( )
 if o0oo0o0O00OO :
  o0oo0o0O00OO . close ( )
 if o0oO :
  if 61 - 61: ii1I * OOooOOo / iiiii . i11iIiiIii . OOOo0
  setKodiProxy ( I1i1iii )
  if 60 - 60: ii11ii1ii / ii11ii1ii
 return ''
 if 46 - 46: OoOO * OOooOOo - o0OoOoOO00 * I1IiI - o00O0oo
def oo0 ( ) :
 import zipfile , StringIO
 i1I1Iiii1111 ( "Checking for new version..." )
 for o00 in os . listdir ( Ooo ) :
  if re . search ( 'changelog-.*.txt' , o00 ) :
   OooOooo = re . search ( 'changelog-(.+?).txt' , o00 )
   OooOooo = OooOooo . group ( 1 )
 try :
  O000oo0O = urllib2 . Request ( "http://parsiland.net/repo/plugin.video.watchparsilandtv/" )
  OOOO = urllib2 . urlopen ( O000oo0O ) . read ( )
 except :
  i1I1Iiii1111 ( "An error happened checking for update" )
  return
 i11i1 = re . search ( r'changelog-(.+?)[.]txt' , OOOO )
 i11i1 = i11i1 . group ( 1 )
 dir = xbmc . translatePath ( os . path . join ( 'special://home/addons/' ) )
 if float ( i11i1 [ 2 : ] ) > float ( OooOooo [ 2 : ] ) :
  i1I1Iiii1111 ( "New version is available. " + i11i1 )
  IIIii1II1II = 'http://parsiland.net/repo/plugin.video.watchparsilandtv/plugin.video.watchparsilandtv-' + i11i1 + ".zip"
  try :
   i11iiII = requests . get ( IIIii1II1II , stream = True )
   if i11iiII . status_code == 200 :
    i1I1iI = zipfile . ZipFile ( StringIO . StringIO ( i11iiII . content ) )
    i1I1iI . extractall ( dir )
    xbmc . executebuiltin ( 'UpdateLocalAddons()' )
    xbmc . executebuiltin ( 'ReloadSkin()' )
    xbmcgui . Dialog ( ) . notification ( "[COLOR red]P[/COLOR][COLOR white]arsiLandTV[/COLOR]" , "Add-on updated" , Ooo + "icon.png" , 3000 , False )
    i1I1Iiii1111 ( "Updated successfully" )
   else : i1I1Iiii1111 ( "Updating wasn't successfull, status_code not OK , " + str ( i11iiII . status_code ) )
  except :
   i1I1Iiii1111 ( "Exception happened! :(" )
   return
 else :
  i1I1Iiii1111 ( "Awesome , You are using latest version." )
  if 93 - 93: OO0O0O % I1IiI * ii1I
  if 16 - 16: Iii1I1 - o00O0oo * OO0O0O + OoOO0ooOOoo0O
oo0 ( )
Ii11iII1 = xbmcgui . Dialog ( )
Oo0O0O0ooO0O = Ii11iII1 . select ( 'Choose a video source' , [ "ParsiLand TV - 960x540 - Link 1" , "ParsiLand TV - 960x540 - Link 2" ] )
if Oo0O0O0ooO0O >= 0 :
 i1I1Iiii1111 ( "selected index : " + str ( Oo0O0O0ooO0O ) )
 o0oOo0Ooo0O = xbmcgui . ListItem ( 'manoto' )
 o0oOo0Ooo0O . setArt ( { 'thumb' : Ooo + "icon.png" } )
 o0oOo0Ooo0O . setInfo ( 'video' , { 'plot' : 'Live Stream' } )
 if Oo0O0O0ooO0O == 0 : IIIIii = "rtmp://vps.parsiland.net:1935/live/ParsiLand"
 elif Oo0O0O0ooO0O == 1 : IIIIii = "http://vps.parsiland.net/hls/ParsiLand.m3u8"
 xbmc . Player ( ) . play ( IIIIii , o0oOo0Ooo0O , False )
else : quit ( )
if 70 - 70: OoOO / ii11ii1ii . OoOO0ooOOoo0O % iIiiiI1IiI1I1
